pages Package — Camelot documentation

### Navigation

- index
- modules |
- Camelot documentation »

# pages Package

## `pages` Package

## `backup_page` Module

class `camelot.view.wizard.pages.backup_page.` `LabelComboBox`(storage, parent=None)

  Bases: `PyQt4.QtGui.QComboBox`

  `filename`()

class `camelot.view.wizard.pages.backup_page.` `LabelLineEdit`(storage, parent=None)

  Bases: `PyQt4.QtGui.QLineEdit`

  `filename`()

class `camelot.view.wizard.pages.backup_page.` `Page`(backup_mechanism=None, parent=None)

  Bases: `PyQt4.QtGui.QWizardPage`

  Abstract class for the select file page of a backup and a restore file.

  `caption` = _('Select file')
  `extension` = '.db'
  `icon` = Icon('tango/32x32/actions/document-save.png')
  `settings_key` = 'custom_backup_filename'
  `sub_title` = _('Please select a backup file. All data in this file will be overwritten.')
  `title` = _('Select backup file')

class `camelot.view.wizard.pages.backup_page.` `SelectBackupFilePage`(backup_mechanism)

  Bases: `camelot.view.wizard.pages.backup_page.Page`

  `isComplete`()

class `camelot.view.wizard.pages.backup_page.` `SelectRestoreFilePage`(parent=None)

  Bases: `camelot.view.wizard.pages.backup_page.Page`

  `icon` = Icon('tango/32x32/devices/drive-harddisk.png')
  `isComplete`()
  `sub_title` = _('Please select a backup file from which to restore the database. All data in the database will be overwritten with data from this file')
  `title` = _('Select restore file')

## `form_page` Module

class `camelot.view.wizard.pages.form_page.` `FormPage`(parent=None)

  Bases: `PyQt4.QtGui.QWizardPage`

  FormPage is a generic wizard page that displays a form for an object in a wizard page, subclass this class to use it. The class attribute ‘Data’ should be the class of the object to be used to store the form information.

  To access the data stored by the wizard form into a data object, use its get_data method.

  The ‘Next’ button will only be activated when the form is complete.

  `Admin` = None
  `Data` = None
  `get_admin`()
  `get_data`()
  `get_icon`()
  `get_sub_title`()
  `get_title`()
  `icon` = Icon('tango/32x32/mimetypes/x-office-spreadsheet.png')
  `initializePage`()
  `isComplete`()
  `sub_title` = None
  `title` = None

## `progress_page` Module

Created on Jan 7, 2010

@author: tw55413

class `camelot.view.wizard.pages.progress_page.` `ProgressPage`(parent=None)

  Bases: `PyQt4.QtGui.QWizardPage`

  Generic progress page for a wizard.

  Subclass and reimplement the run method. And within this run method, regulary emit the update_progress_signal and the update_maximum_signal.

  the update_maximum_signal should have as its single argument an integer value indicating the maximum of the progress bar.

  the update_progress_signal should two arguments, the first is an integer indicating the current position of the progress bar, and the second is a string telling the user what is going on.

  If required, set the title and sub_title class attribute to change the text displayed to the user.

  `exception`(args)
  `finished`()
  `initializePage`()
  `isComplete`()
  `run`()

    This method contains the actual action, that will be run in the model thread.

    Reimplement this method, while regulary emiting update_progress_signal and update_maximum_signal to keep the progress bar moving.

  `sub_title` = _('Please wait for completion')
  `title` = _('Action in progress')
  `update_maximum`(maximum)
  `update_maximum_signal`
  `update_progress`(value, label)
  `update_progress_signal`

## `select` Module

class `camelot.view.wizard.pages.select.` `SelectFilePage`(parent=None)

  Bases: `PyQt4.QtGui.QWizardPage`

  SelectFilePage is the file selection page of an import wizard

  `caption` = _('Select file')
  `icon` = Icon('tango/32x32/mimetypes/x-office-spreadsheet.png')
  `save` = False
  `setpath`()
  `sub_title` = _('To import data, click 'Browse' to select a file then click 'Next'.')
  `title` = _('Import data from a file')

## `update_entities_page` Module

Created on Jan 18, 2010

@author: tw55413

class `camelot.view.wizard.pages.update_entities_page.` `UpdateEntitiesPage`(collection_getter, parent)

  Bases: `camelot.view.wizard.pages.progress_page.ProgressPage`

  A progress page that updates each entity in a collection, then flushes the entity, and informs all views that the entity has been updated. Subclass this page and implement update_entity to make this page do something.

  `run`()
  `update_entity`(entity)

    Implement this method to update the entities in the collection.

    Parameters: | entity – the entity that should be updated
    Returns: | None or a string that will be displayed in the progress

    screen.

### Navigation

- index
- modules |
- Camelot documentation »

Comments
blog comments powered by Disqus